# Development and Contribution #

- You are welcome to contribute, fix bugs, and augment SOS by missing features!

    - Please ask for assignment of an issue
    - Send in your pull requests from any of your local branches (or your `master`) against `master`
- This project uses simplistic trunk-based development for the same reason SOS was originally developed - it's much more natural to the (lone) developer than feature- and release-branching and simply does what most developers want - to regularly save the current development state to the VCS
- Note that SOS is currently developed using a private SVN repository which gets mirrored from time to time to Github.
